
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.20.3rc2',
    'branch_nick': 'patch-0-Release__1_20_3rc2_preparation',
    'revision_id': 'b6e99b6a0b7b7c753dc12314c53406d8fe5604e0',
    'revno': 8408
}
